﻿using Hotline.Share.Dtos;
using Hotline.Share.Dtos.Article;
using Hotline.Share.Dtos.Snapshot;

namespace Hotline.Application.Snapshot;
public interface ISnapshotApplication
{
    /// <summary>
    /// 获取用户首页数据
    /// </summary>
    /// <returns></returns>
    Task<SnapshotUserInfoOutDto> GetSnapshotUserInfoAsync();

    /// <summary>
    /// 获取小程序首页数据
    /// </summary>
    /// <returns></returns>
    Task<HomePageOutDto> GetHomePageAsync();

    /// <summary>
    /// 获取小程序公告列表
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    Task<IReadOnlyList<BulletinOutDto>> GetBulletinsAsync(BulletinInDto dto);
    
    /// <summary>
    /// 获取工单列表
    /// </summary>
    Task<PagedDto<OrderOutDto>> GetSnapshotOrdersAsync(OrderInDto dto);

    /// <summary>
    /// 获取工单详情
    /// </summary>
    /// <param name="id"></param>
    /// <returns></returns>
    Task<OrderDetailOutDto> GetSnapshotOrderDetailAsync(string id);

    /// <summary>
    /// 统计红包金额, 每月的总金额
    /// </summary>
    /// <param name="count"></param>
    /// <returns></returns>
    Task<IReadOnlyList<RedPackDateOutDto>> GetRedPackDateAsync(RedPackDateInDto dto);

    /// <summary>
    /// 获取当月详细红包列表
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    Task<PagedDto<RedPackOutDto>> GetRedPacksAsync(RedPacksInDto dto);

    /// <summary>
    /// 获取公告详情
    /// </summary>
    /// <param name="id"></param>
    /// <returns></returns>
    Task<BulletinOutDto> GetBulletinsDetailAsync(string id);

    /// <summary>
    /// 获取行业界面基础数据
    /// </summary>
    /// <param name="id"></param>
    /// <param name="requestAborted"></param>
    /// <returns></returns>
    Task<IndustryBaseOutDto> GetIndustryBaseAsync(string id, CancellationToken requestAborted);
}
