﻿using Hotline.Share.Dtos.Settings;
using Hotline.Share.Enums.Snapshot;
using XF.Utility.EnumExtensions;

namespace Hotline.Share.Dtos.Snapshot;

/// <summary>
/// 微信小程序首页数据
/// </summary>
public class HomePageOutDto
{
    /// <summary>
    /// Banner图片集合
    /// </summary>
    public List<string> Banners { get; set; } = new List<string>();

    /// <summary>
    /// 行业集合
    /// </summary>
    public List<HomeIndustryOutDto> Industrys { get; set; }
}

public class HomeIndustryOutDto
{ 
    /// <summary>
    /// 行业Id
    /// </summary>
    public string Id { get; set; }

    /// <summary>
    /// 名字
    /// </summary>
    public string Name { get; set; }

    /// <summary>
    /// 帮助引导用语
    /// </summary>
    public string? TxtHelpRemarks { get; set; }

    /// <summary>
    /// 宫格说明文本
    /// </summary>
    public string? TxtRemarks { get; set; }

    /// <summary>
    /// 关怀说明
    /// </summary>
    public string? TxtCareRemarks { get; set; }

    /// <summary>
    /// 排序
    /// </summary>
    public int DisplayOrder { get; set; }

    /// <summary>
    /// 页面Url
    /// </summary>
    public string? PageUrl { get; set; }

    /// <summary>
    /// 关怀页面Url
    /// </summary>
    public string? PageCareUrl { get; set; }

    /// <summary>
    /// 背景图片 url
    /// </summary>
    public string? BackgroundImgUrl { get; set; }

    /// <summary>
    /// Banner 图片 url
    /// </summary>
    public string? BannerImgUrl { get; set; }

    /// <summary>
    /// 宫格图
    /// </summary>
    public string? CellImgUrl { get; set; }

    /// <summary>
    /// 关怀宫格图
    /// </summary>
    public string? CareCellImgUrl { get; set; }

    /// <summary>
    /// 行业类型
    /// </summary>
    public EIndustryType IndustryType { get; set; }

    /// <summary>
    /// 行业类型Text
    /// </summary>
    public string IndustryTypeTxt => IndustryType.GetDescription();
}

public class IndustryOutDto
{ 
    /// <summary>
    /// Id
    /// </summary>
    public string Id { get; set; }

    /// <summary>
    /// 名字
    /// </summary>
    public string Name { get; set; }

    /// <summary>
    /// 帮助引导用语
    /// </summary>
    public string? TxtHelpRemarks { get; set; }
}

public class IndustryBaseOutDto
{
    /// <summary>
    /// 行业信息
    /// </summary>
    public IndustryOutDto Industry { get; set; }

    /// <summary>
    /// 区域集合
    /// </summary>
    public IList<SystemAreaOutDto> AreaTree { get; set; } = [];

    /// <summary>
    /// 附件集合
    /// </summary>
    public IList<IndustryFileDto> Files { get; set; } = [];

    /// <summary>
    /// 作业场所
    /// </summary>
    public IList<SystemDicDataOutDto> Workplace { get; set; }
    public IList<SystemDicDataOutDto> WorkArea { get; set; }
}