﻿using Hotline.Share.Enums.Snapshot;
using Hotline.Share.Enums.User;

namespace Hotline.Share.Dtos.Snapshot;

public class TokenOutDto
{
    public TokenOutDto(EReadPackUserType citizenType, string token)
    {
        UserType = citizenType;
        Token = token;
    }

    /// <summary>
    /// 用户类型
    /// </summary>
    public EReadPackUserType UserType { get; set; }

    /// <summary>
    /// 登录token
    /// </summary>
    public string Token { get; set; }
}

public class ThirdTokenInDto
{
    /// <summary>
    /// 微信小程序登录Code
    /// </summary>
    public string LoginCode { get; set; }

    /// <summary>
    /// 微信小程序手机号Code
    /// </summary>
    public string TelCode { get; set; }

    /// <summary>
    /// 第三方平台类型(不传默认微信)
    /// 0: 微信
    /// </summary>
    public EThirdType ThirdType { get; set; } = EThirdType.WeChat;
}

public class ThirdPhoneInDto : ThirdTokenInDto { }

public class ThirdPhoneOutDto
{
    /// <summary>
    /// 电话号码
    /// </summary>
    public string PhoneNumber { get; set; }

    /// <summary>
    /// 是否异常
    /// </summary>
    public bool IsError { get; set; }

    /// <summary>
    /// 微信返回异常信息
    /// </summary>
    public string ErrorMessage { get; set; }

    /// <summary>
    /// 微信返回异常Code
    /// </summary>
    public int ErrorCode { get; set; }
}

public class ThirdTokenOutDto
{
    public string SessionKey { get; set; }
    public string OpenId { get; set; }
}

public class ThirdTokenDto : ThirdTokenInDto
{
    /// <summary>
    /// 微信AppId
    /// </summary>
    public string AppId { get; set; }

    /// <summary>
    /// 微信AppSecret
    /// </summary>
    public string Secret { get; set; }
}
